#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const main_1 = __importDefault(require("../main"));
const swagger_parser_1 = __importDefault(require("@apidevtools/swagger-parser"));
const isOpenApiV3Document = (api) => {
    return !!api.openapi;
};
commander_1.program
    .description('Generates Angular Reactive Forms templates from openapi yaml/json file to output dir')
    .version('1.0.0')
    .option('-i, --input', 'Path to openapi file')
    .option('-o, --output', 'Path to dir for output files')
    .arguments('<input> <output>')
    .action(async (inputFilePath, outputFilePath) => {
    try {
        const writeFile = async ({ name, content }) => {
            const fullName = `${name}.ts`;
            const fullPath = path_1.default.join(outputFilePath, fullName);
            await fs_1.promises.writeFile(fullPath, content, { encoding: 'utf-8' });
        };
        const options = {
            dereference: {
                circular: true,
            },
            validate: {
                schema: true
            }
        };
        const api = await swagger_parser_1.default.validate(inputFilePath, options);
        if (!isOpenApiV3Document(api)) {
            throw new Error('Current version of library supports only OpenApi versions 3.0 and above.');
        }
        const generatedFileContents = main_1.default(api);
        await fs_1.promises.mkdir(outputFilePath, { recursive: true });
        await Promise.all(generatedFileContents.map(writeFile));
        // eslint-disable-next-line no-console
        console.log(`Generating files successfully completed. Files created at path: ${outputFilePath} (click link to open)`);
    }
    catch (error) {
        // eslint-disable-next-line no-console
        console.error('Something went wrong: %s', error);
    }
})
    .parse(process.argv);
//# sourceMappingURL=index.js.map