export declare type DefaultValueType = string | number | boolean | null;
export declare enum DataType {
    Object = "object",
    Array = "array",
    String = "string",
    Boolean = "boolean",
    Integer = "integer",
    Number = "number"
}
export declare type PrimitiveDataType = DataType.Boolean | DataType.String | DataType.Integer;
export declare type ArrayDataType = DataType.Array;
export declare type NonArrayDataType = PrimitiveDataType | DataType.Object;
export declare type Definition = {
    enum?: Array<unknown>;
    format?: string;
    pattern?: string;
    minimum?: number;
    maximum?: number;
    readOnly?: boolean;
    writeOnly?: boolean;
    minLength?: number;
    maxLength?: number;
    required?: boolean;
    default?: DefaultValueType;
    isGroup: boolean;
};
export declare type PlainDefinition = Definition & {
    type: PrimitiveDataType;
};
export declare type ObjectDefinition = Definition & {
    type: DataType.Object;
    properties: Property;
    requiredFields: Array<string>;
};
export declare type ArrayDefinition = Definition & {
    type: DataType.Array;
    items?: NonArrayDataType[];
};
export declare type Schema = PlainDefinition | ObjectDefinition | ArrayDefinition;
export declare type NonArrayDefinition = PlainDefinition | ObjectDefinition;
export declare type MergedDefinition = Definition & {
    type: DataType.Object | DataType.String | DataType.Boolean | DataType.Integer;
    allOf: Array<Schema | MergedDefinition>;
};
export declare type Property = {
    [name: string]: Schema;
};
export declare type SchemaDefinition = Schema | MergedDefinition;
export interface ObjectEntity {
    name: string;
    value: ObjectDefinition;
}
export interface ArrayEntity {
    name: string;
    value: ArrayDefinition;
}
export interface PlainEntity {
    name: string;
    value: PlainDefinition;
}
export declare type Entity = {
    name: string;
    value: ObjectDefinition | ArrayDefinition | PlainDefinition;
};
declare type Keys<T> = keyof (Required<T>);
declare type Values<T> = (Required<T>)[keyof T];
export declare type DefinitionKeys = Keys<Definition>;
export declare type DefinitionValues = Values<Definition>;
export {};
