"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prettier_1 = __importDefault(require("prettier"));
const normalize_1 = __importDefault(require("./services/normalize"));
const utils_1 = require("./services/utils");
const types_adapter_1 = __importDefault(require("./services/types-adapter"));
const node_builder_1 = __importDefault(require("./services/node-builder"));
const buildImports = () => {
    return `
  /* tslint:disable */
  /* eslint-disable */
  import { FormGroup, FormControl, FormArray, Validators } from '@angular/forms';
  
  `;
};
const buildFileContent = (node) => {
    const imports = buildImports();
    const body = node.build();
    const text = `${imports}\n${body}`;
    return prettier_1.default.format(text, {
        parser: 'typescript',
        singleQuote: true,
        trailingComma: 'es5',
        tabWidth: 2
    });
};
const isInterfaceName = (value) => (/^i/i).test(value);
function main(api) {
    var _a;
    const { components } = api;
    const schemas = (_a = components === null || components === void 0 ? void 0 : components.schemas) !== null && _a !== void 0 ? _a : {};
    const entities = Object.entries(schemas)
        .map(([name, value]) => {
        return {
            name,
            value: value
        };
    });
    return entities
        .filter(({ name }) => !isInterfaceName(name))
        .map(({ name, value }) => ({ name, value: types_adapter_1.default(value) }))
        .map(({ name, value }) => ({ name, value: normalize_1.default(value) }))
        .filter(utils_1.hasPresentKey('value'))
        .filter(({ value }) => value.isGroup)
        .map(entity => node_builder_1.default(entity))
        .map(node => ({
        name: node.name,
        content: buildFileContent(node)
    }));
}
exports.default = main;
//# sourceMappingURL=main.js.map