"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../services/utils");
const baseNode_1 = __importDefault(require("./baseNode"));
class GroupNode extends baseNode_1.default {
    constructor({ name, value }, childMapper, parent) {
        super(name, 'group');
        const { properties, requiredFields } = value;
        if (requiredFields && properties) {
            const allControlsNames = Object.keys(properties);
            requiredFields.forEach((propName) => {
                if (allControlsNames.includes(propName)) {
                    properties[propName] = { ...properties[propName], required: true };
                }
            });
        }
        const rawChildren = Object.entries(properties);
        this.children = rawChildren.map((rawChild) => {
            const [name, value] = rawChild;
            const entity = { name, value };
            return childMapper(entity, this);
        });
        this.parent = parent;
    }
    static buildUpperNode(name, body) {
        return `const ${name} = new FormGroup({
      ${body}}
    );
    
    export default ${name};`;
    }
    static buildInnerNode(name, body) {
        return `${name}: new FormGroup({
      ${body}
    })`;
    }
    build() {
        const { name } = this;
        const body = this.children.map((child) => child.build()).join(',');
        const isInnerNode = !utils_1.isNil(this.parent);
        return isInnerNode ? GroupNode.buildInnerNode(name, body) : GroupNode.buildUpperNode(name, body);
    }
}
exports.default = GroupNode;
//# sourceMappingURL=groupNode.js.map