"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ngx_openapi_types_1 = require("../contracts/ngx-openapi-types");
const utils_1 = require("./utils");
const mergeDefinitions = (definitions) => {
    const definition = {
        type: ngx_openapi_types_1.DataType.Object,
        properties: {},
        requiredFields: [],
        isGroup: true
    };
    return definitions.reduce((acc, currentDefinition) => {
        if (!utils_1.isObjectDefinition(currentDefinition)) {
            return acc;
        }
        const props = { ...acc.properties, ...currentDefinition.properties };
        const requiredFields = [...acc.requiredFields, ...currentDefinition.requiredFields];
        acc.properties = props;
        acc.requiredFields = requiredFields;
        return acc;
    }, definition);
};
const processMergedDefinition = (definition) => {
    const { allOf } = definition;
    const flattedDefinitions = allOf.reduce((acc, innerDef) => {
        if (utils_1.isMergedDefinition(innerDef)) {
            const norm = normalize(innerDef);
            norm && acc.push(norm);
        }
        else {
            acc.push(innerDef);
        }
        return acc;
    }, []);
    return mergeDefinitions(flattedDefinitions);
};
const processObjectDefinition = (definition) => {
    const { properties } = definition;
    const names = Object.keys(properties);
    const props = names.reduce((acc, name) => {
        const value = properties[name];
        if (utils_1.isMergedDefinition(value)) {
            const flatted = normalize(value);
            return flatted ? ({ ...acc, [name]: flatted.properties }) : acc;
        }
        else {
            return ({ ...acc, [name]: value });
        }
    }, {});
    return {
        type: ngx_openapi_types_1.DataType.Object,
        properties: props
    };
};
const mappers = [
    {
        check: (schema) => utils_1.isPrimitive(schema) || utils_1.isEnum(schema) || utils_1.isArrayDefinition(schema),
        transform: () => null,
    },
    {
        check: (schema) => utils_1.isMergedDefinition(schema),
        transform: (schema) => processMergedDefinition(schema),
    },
    {
        check: (schema) => utils_1.isObjectDefinition(schema),
        transform: (schema) => processObjectDefinition(schema),
    }
];
const normalize = (entity) => {
    const rule = mappers.find(({ check }) => check(entity));
    if (rule) {
        const { transform } = rule;
        return transform(entity);
    }
    throw new Error(`Normalize rules not found for entity: ${JSON.stringify(entity)}`);
};
exports.default = normalize;
//# sourceMappingURL=normalize.js.map