"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ngx_openapi_types_1 = require("../contracts/ngx-openapi-types");
const utils_1 = require("./utils");
const objectMapper = (from) => {
    var _a, _b;
    const properties = (_a = from.properties) !== null && _a !== void 0 ? _a : {};
    // TODO: should we process this fields?
    // const mappedProperties = Object.keys(properties).reduce(
    //     (acc: Property, currentProperty: string) => {
    //         const value = properties[currentProperty];
    //         const mapper = getMapper(value as OpenAPIV3.SchemaObject);
    //         const transformedValue = mapper(value as OpenAPIV3.SchemaObject);
    //         if (isMergedDefinition(transformedValue)) {
    //             throw new Error(`Schema can not be complex! Shema: ${JSON.stringify(value)}`);
    //         }
    //         acc[currentProperty] = transformedValue;
    //         return acc;
    //     },
    //     <Property>{}
    // )
    return {
        type: ngx_openapi_types_1.DataType.Object,
        properties: properties,
        requiredFields: (_b = from.required) !== null && _b !== void 0 ? _b : [],
        isGroup: true
    };
};
const arrayMapper = (from) => {
    const cast = from;
    return {
        type: ngx_openapi_types_1.DataType.Array,
        items: cast.items,
        isGroup: false
    };
};
const plainMapper = (from) => {
    return {
        type: from.type,
        format: from.format,
        pattern: from.pattern,
        minimum: from.minimum,
        maximum: from.maximum,
        minLength: from.minLength,
        maxLength: from.maxLength,
        readOnly: from.readOnly,
        default: from.default,
        isGroup: false
    };
};
const complexMapper = (from) => {
    var _a, _b;
    const mappedAllOf = (_b = (_a = from.allOf) === null || _a === void 0 ? void 0 : _a.map(x => {
        const mapper = getMapper(x);
        return mapper(x);
    })) !== null && _b !== void 0 ? _b : [];
    return {
        type: ngx_openapi_types_1.DataType.Object,
        isGroup: true,
        allOf: mappedAllOf
    };
};
const typeDispatcher = (fromType) => {
    switch (fromType) {
        case ngx_openapi_types_1.DataType.Object:
            return objectMapper;
        case ngx_openapi_types_1.DataType.Array:
            return arrayMapper;
        case ngx_openapi_types_1.DataType.Boolean:
        case ngx_openapi_types_1.DataType.Integer:
        case ngx_openapi_types_1.DataType.Number:
        case ngx_openapi_types_1.DataType.String:
            return plainMapper;
        default:
            return null;
    }
};
const complexDispatcher = (from) => {
    if (!utils_1.isNil(from.allOf) && (utils_1.isNil(from.type) || from.type === ngx_openapi_types_1.DataType.Object)) {
        return complexMapper;
    }
    return null;
};
const getMapper = (from) => {
    var _a;
    const mappingFn = (_a = complexDispatcher(from)) !== null && _a !== void 0 ? _a : typeDispatcher(from.type);
    if (utils_1.isNil(mappingFn)) {
        throw new Error(`Can not map schema: ${JSON.stringify(from)}`);
    }
    return mappingFn;
};
exports.default = (from) => {
    const mapper = getMapper(from);
    return mapper(from);
};
//# sourceMappingURL=types-adapter.js.map