"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../services/utils");
var BasicValidators;
(function (BasicValidators) {
    BasicValidators["Email"] = "email";
    BasicValidators["Pattern"] = "pattern";
    BasicValidators["Required"] = "required";
    BasicValidators["MinLength"] = "minLength";
    BasicValidators["MaxLength"] = "maxLength";
    BasicValidators["MinValue"] = "min";
    BasicValidators["MaxValue"] = "max";
})(BasicValidators || (BasicValidators = {}));
const buildValidator = (type, value) => utils_1.isNil(value) ? `Validators.${type}` : `Validators.${type}(${value})`;
const mapper = [
    {
        check: (name) => name === 'format',
        process: (value) => (value === 'email' ? 'Validators.email' : null),
    },
    {
        check: (name) => name === 'pattern',
        process: (value) => buildValidator(BasicValidators.Pattern, `/${value}/`),
    },
    {
        check: (name) => name === 'required',
        process: () => buildValidator(BasicValidators.Required),
    },
    {
        check: (name) => name === 'minLength',
        process: (value) => buildValidator(BasicValidators.MinLength, value),
    },
    {
        check: (name) => name === 'maxLength',
        process: (value) => buildValidator(BasicValidators.MaxLength, value),
    },
    {
        check: (name) => name === 'minimum',
        process: (value) => buildValidator(BasicValidators.MinValue, value),
    },
    {
        check: (name) => name === 'maximum',
        process: (value) => buildValidator(BasicValidators.MaxValue, value),
    },
];
exports.default = (key, value) => {
    const rule = mapper.find(({ check }) => check(key));
    if (!rule) {
        return null;
    }
    const { process } = rule;
    return process(value);
};
//# sourceMappingURL=rules.js.map